@@ -1,22 +1,3 @@
-
-# ------------------------------------------------------------------------ #
-#
-# Descriptif : Awesome Radio
-#        via : http://flatlogic.github.io/awesome-bootstrap-checkbox/demo/
-#
-#
-# Auteurs : Victor PERRIER
-#
-# Date creation : 23/08/2016
-# Date modification : 23/08/2016
-#
-# Version 1.0
-#
-# ------------------------------------------------------------------------ #
-
-
-
-
 #' @title Awesome Checkbox Input Control
 #'
 #' @description
@@ -37,12 +18,10 @@
 #' if (interactive()) {
 #'
 #' ui <- fluidPage(
-#'  awesomeCheckboxGroup(
-#'   inputId = "Id001",
-#'   label = "Checkboxes with status",
-#'   choices = c("A", "B", "C"),
-#'   inline = TRUE, status = "danger"
-#'  ),
+#'  awesomeCheckbox(inputId = "somevalue",
+#'                  label = "A single checkbox",
+#'                  value = TRUE,
+#'                  status = "danger"),
 #'  verbatimTextOutput("value")
 #' )
 #' server <- function(input, output) {
@@ -52,22 +31,23 @@
 #' }
 #' }
 #'
-#' @import shiny
+#' @importFrom shiny restoreInput
 #' @importFrom htmltools htmlDependency attachDependencies
 #'
 #' @export
 awesomeCheckbox <- function (inputId, label, value = FALSE, status = "primary", width = NULL)
 {
+  value <- shiny::restoreInput(id = inputId, default = value)
   status <- match.arg(arg = status, choices = c("primary", "success", "info", "warning", "danger"))
-  inputTag <- tags$input(id = inputId, type = "checkbox")
+  inputTag <- htmltools::tags$input(id = inputId, type = "checkbox")
   if (!is.null(value) && value)
     inputTag$attribs$checked <- "checked"
-  awesomeTag <- div(class = "form-group shiny-input-container", style = if (!is.null(width))
-    paste0("width: ", validateCssUnit(width), ";"),
-    div(class = paste0("checkboxbs checkbox-bs checkbox-bs-", status),
+  awesomeTag <- htmltools::tags$div(class = "form-group shiny-input-container", style = if (!is.null(width))
+    paste0("width: ", htmltools::validateCssUnit(width), ";"),
+    htmltools::tags$div(class = paste0("checkboxbs checkbox-bs checkbox-bs-", status),
         style = "margin-top: 10px; margin-bottom: 10px;",
         inputTag,
-        tags$label(tags$span(label, style = "font-weight: normal; cursor: pointer;"), `for` = inputId)))
+        htmltools::tags$label(tags$span(label, style = "font-weight: normal; cursor: pointer;"), `for` = inputId)))
   # Dep
   attachShinyWidgetsDep(awesomeTag, "awesome")
 }
@@ -82,23 +62,23 @@ generateAwesomeOptions <- function (inputId, choices, selected, inline, status)
 {
   options <- mapply(choices, names(choices), FUN = function(value,
                                                             name) {
-    inputTag <- tags$input(type = "checkbox", name = inputId, value = value, id = paste0(inputId, value))
+    inputTag <- htmltools::tags$input(type = "checkbox", name = inputId, value = value, id = paste0(inputId, value))
     if (value %in% selected)
       inputTag$attribs$checked <- "checked"
     if (inline) {
       # tags$label(class = paste0("checkbox", "-inline"), inputTag,
       #            tags$span(name))
-      tags$div(class = paste0("awesome-checkbox checkbox-bs checkbox-bs-inline checkbox-inline checkbox-bs-", status),
+      htmltools::tags$div(class = paste0("awesome-checkbox checkbox-bs checkbox-bs-inline checkbox-inline checkbox-bs-", status),
                style = "margin-top: -4px;",
                inputTag, tags$label(style = "font-weight: normal;", name, `for` = paste0(inputId, value)))
     }
     else {
-      tags$div(class = paste0("awesome-checkbox checkbox-bs checkbox-bs-", status),
+      htmltools::tags$div(class = paste0("awesome-checkbox checkbox-bs checkbox-bs-", status),
                style = "margin-top: -3px;",
                inputTag, tags$label(style = "font-weight: normal;", name, `for` = paste0(inputId, value)))
     }
   }, SIMPLIFY = FALSE, USE.NAMES = FALSE)
-  div(class = "shiny-options-group", options)
+  htmltools::tags$div(class = "shiny-options-group", options)
 }
 
 
@@ -121,23 +101,64 @@ generateAwesomeOptions <- function (inputId, choices, selected, inline, status)
 #'
 #' @seealso \code{\link{updateAwesomeCheckboxGroup}}
 #'
-#' @import shiny
-#' @importFrom htmltools htmlDependency attachDependencies
+#' @importFrom shiny restoreInput
+#' @importFrom htmltools tags validateCssUnit
 #'
 #' @export
+#'
+#' @examples
+#'
+#' \dontrun{
+#' if (interactive()) {
+#'
+#'
+#' ui <- fluidPage(
+#'   br(),
+#'   awesomeCheckboxGroup(
+#'     inputId = "id1", label = "Make a choice:",
+#'     choices = c("graphics", "ggplot2")
+#'   ),
+#'   verbatimTextOutput(outputId = "res1"),
+#'   br(),
+#'   awesomeCheckboxGroup(
+#'     inputId = "id2", label = "Make a choice:",
+#'     choices = c("base", "dplyr", "data.table"),
+#'     inline = TRUE, status = "danger"
+#'   ),
+#'   verbatimTextOutput(outputId = "res2")
+#' )
+#'
+#' server <- function(input, output, session) {
+#'
+#'   output$res1 <- renderPrint({
+#'     input$id1
+#'   })
+#'
+#'   output$res2 <- renderPrint({
+#'     input$id2
+#'   })
+#'
+#' }
+#'
+#' shinyApp(ui = ui, server = server)
+#'
+#'
+#' }
+#' }
 awesomeCheckboxGroup <- function (inputId, label, choices, selected = NULL, inline = FALSE, status = "primary",
           width = NULL)
 {
   choices <- choicesWithNames(choices)
+  selected <- shiny::restoreInput(id = inputId, default = selected)
   if (!is.null(selected))
     selected <- validateSelected(selected, choices, inputId)
   options <- generateAwesomeOptions(inputId, choices, selected, inline, status = status)
-  divClass <- "form-group shiny-input-checkboxgroup shiny-input-container"
+  divClass <- "form-group shiny-input-container"
   if (inline)
-    divClass <- paste(divClass, "shiny-input-container-inline")
-  awesomeTag <- tags$div(id = inputId, style = if (!is.null(width))
-    paste0("width: ", validateCssUnit(width), ";"), class = divClass,
-    tags$label(label, `for` = inputId, style = "margin-bottom: 10px;"), options)
+    divClass <- paste(divClass, "shiny-input-container-inline shiny-input-checkboxgroup")
+  awesomeTag <- htmltools::tags$div(id = inputId, style = if (!is.null(width))
+    paste0("width: ", htmltools::validateCssUnit(width), ";"), class = divClass,
+    htmltools::tags$label(label, `for` = inputId, style = "margin-bottom: 10px;"), options)
   # Dep
   attachShinyWidgetsDep(awesomeTag, "awesome")
 }
