@@ -23,8 +23,7 @@
 #' @seealso \code{\link{animateOptions}} for animation, \code{\link{tooltipOptions}} for tooltip and
 #' \code{\link{actionBttn}} for the button.
 #'
-#' @import shiny
-#' @importFrom htmltools validateCssUnit tagList singleton
+#' @importFrom htmltools validateCssUnit tagList singleton tags tagAppendChild
 #'
 #' @export
 #' @examples
@@ -32,15 +31,69 @@
 #' ## Only run examples in interactive R sessions
 #' if (interactive()) {
 #'
-#' dropdown(
-#'   "Content goes here",
-#'   style = "unite", icon = icon("gear"), status = "danger", width = "300px",
-#'   animate = animateOptions(
-#'     enter = animations$fading_entrances$fadeInLeftBig,
-#'     exit = animations$fading_exits$fadeOutRightBig
-#'   )
+#' library("shiny")
+#' library("shinyWidgets")
+#'
+#' ui <- fluidPage(
+#'   tags$h2("pickerInput in dropdown"),
+#'   br(),
+#'   dropdown(
+#'
+#'     tags$h3("List of Input"),
+#'
+#'     pickerInput(inputId = 'xcol2',
+#'                 label = 'X Variable',
+#'                 choices = names(iris),
+#'                 options = list(`style` = "btn-info")),
+#'
+#'     pickerInput(inputId = 'ycol2',
+#'                 label = 'Y Variable',
+#'                 choices = names(iris),
+#'                 selected = names(iris)[[2]],
+#'                 options = list(`style` = "btn-warning")),
+#'
+#'     sliderInput(inputId = 'clusters2',
+#'                 label = 'Cluster count',
+#'                 value = 3,
+#'                 min = 1, max = 9),
+#'
+#'     style = "unite", icon = icon("gear"),
+#'     status = "danger", width = "300px",
+#'     animate = animateOptions(
+#'       enter = animations$fading_entrances$fadeInLeftBig,
+#'       exit = animations$fading_exits$fadeOutRightBig
+#'     )
+#'   ),
+#'
+#'   plotOutput(outputId = 'plot2')
 #' )
 #'
+#' server <- function(input, output, session) {
+#'
+#'   selectedData2 <- reactive({
+#'     iris[, c(input$xcol2, input$ycol2)]
+#'   })
+#'
+#'   clusters2 <- reactive({
+#'     kmeans(selectedData2(), input$clusters2)
+#'   })
+#'
+#'   output$plot2 <- renderPlot({
+#'     palette(c("#E41A1C", "#377EB8", "#4DAF4A",
+#'               "#984EA3", "#FF7F00", "#FFFF33",
+#'               "#A65628", "#F781BF", "#999999"))
+#'
+#'     par(mar = c(5.1, 4.1, 0, 1))
+#'     plot(selectedData2(),
+#'          col = clusters2()$cluster,
+#'          pch = 20, cex = 3)
+#'     points(clusters2()$centers, pch = 4, cex = 4, lwd = 4)
+#'   })
+#'
+#' }
+#'
+#' shinyApp(ui = ui, server = server)
+#'
 #' }
 #' }
 dropdown <- function(..., style = "default", status = "default", size = "md", icon = NULL,
@@ -53,7 +106,7 @@ dropdown <- function(..., style = "default", status = "default", size = "md", ic
   contentId <- paste0("sw-content-", alea)
 
   # Dropdown content
-  dropcontent <- tags$div(
+  dropcontent <- htmltools::tags$div(
     id=contentId, class="sw-dropdown-content animated",
     class=if(up) "sw-dropup-content", class=if(right) "sw-dropright-content",
     style=if(!is.null(width)) paste("width:", htmltools::validateCssUnit(width)),
@@ -67,17 +120,23 @@ dropdown <- function(..., style = "default", status = "default", size = "md", ic
       choices = c("default", "primary", "success", "info", "warning", "danger")
     )
     btn <- tags$button(
-      class = paste0("btn btn-", status," ", ifelse(size == "default" | size == "md", "", paste0("btn-", size))),
+      class = paste0("btn btn-", status," ",
+                     ifelse(size == "default" | size == "md", "",
+                            paste0("btn-", size))),
       type = "button", id = btnId, list(icon, label),
-      tags$span(class = ifelse(up, "glyphicon glyphicon-triangle-top", "glyphicon glyphicon-triangle-bottom"))
+      htmltools::tags$span(class = ifelse(test = up,
+                               yes = "glyphicon glyphicon-triangle-top",
+                               no = "glyphicon glyphicon-triangle-bottom"))
     )
   } else {
-    btn <- actionBttn(inputId = btnId, label = label, icon = icon, style = style, color = status, size = size)
+    btn <- actionBttn(inputId = btnId, label = label,
+                      icon = icon, style = style,
+                      color = status, size = size)
   }
 
 
   # Final tag
-  dropdownTag <- tags$div(class = "sw-dropdown", id=dropId, btn, dropcontent)
+  dropdownTag <- htmltools::tags$div(class = "sw-dropdown", id=dropId, btn, dropcontent)
 
 
   # Tooltip
@@ -92,7 +151,7 @@ dropdown <- function(..., style = "default", status = "default", size = "md", ic
         "false"
       else x
     })
-    tooltipJs <- tags$script(
+    tooltipJs <- htmltools::tags$script(
       sprintf(
         "$('#%s').tooltip({ placement: '%s', title: '%s', html: %s });",
         btnId, tooltip$placement, tooltip$title, tooltip$html
@@ -107,7 +166,7 @@ dropdown <- function(..., style = "default", status = "default", size = "md", ic
 
   if (!is.null(animate) && !identical(animate, FALSE)) {
     dropdownTag <- htmltools::tagAppendChild(
-      dropdownTag,tags$script(
+      dropdownTag, htmltools::tags$script(
         sprintf(
           "$(function() {swDrop('%s', '%s', '%s', '%s', '%s', '%s');});",
           btnId, contentId, dropId,
@@ -118,7 +177,7 @@ dropdown <- function(..., style = "default", status = "default", size = "md", ic
     dropdownTag <- attachShinyWidgetsDep(dropdownTag, "animate")
   } else {
     dropdownTag <- htmltools::tagAppendChild(
-      dropdownTag,tags$script(
+      dropdownTag, htmltools::tags$script(
         sprintf(
           "$(function() {swDrop('%s', '%s', '%s', '%s', '%s', '%s');});",
           btnId, contentId, dropId, "sw-none", "sw-none", "1"
